@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import (
     ChannelMembershipTypeType,
@@ -141,7 +141,7 @@ _RequiredBatchCreateChannelMembershipRequestRequestTypeDef = TypedDict(
     "_RequiredBatchCreateChannelMembershipRequestRequestTypeDef",
     {
         "ChannelArn": str,
-        "MemberArns": List[str],
+        "MemberArns": Sequence[str],
         "ChimeBearer": str,
     },
 )
@@ -379,7 +379,7 @@ _OptionalCreateChannelRequestRequestTypeDef = TypedDict(
         "Mode": ChannelModeType,
         "Privacy": ChannelPrivacyType,
         "Metadata": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
